@@ -206,7 +206,12 @@ class MikrotikApiClient:
             elif reply == '!trap':  # wait for done to return
                 err = MikrotikApiError(attrs.get('=message'))
             elif reply == '!fatal':
-                raise MikrotikApiError(list(attrs.keys())[0])
+                reason = list(attrs.keys())[0]
+                if reason == "too many commands before login":
+                    # PPA-923 we want to let the caller continue in this case.
+                    await self.close()
+                    return await self.talk(words)
+                raise MikrotikApiError(reason)
 
     async def read(self):
         """Read a result from the API."""
